import { View, Text } from "@tarojs/components"
import { useEffect, useState, useMemo } from "react"
import Taro from "@tarojs/taro"
import CustomNav from '@/components/CustomNav'
import ButtontWX from '@/components/ButtontWX'
import AssessModel from "@/components/AssessModel"
import withLayout from '@/layouts'
import formatTimes from "@/utils/codeSegment"
import formatPrice from "@/utils/formatPrice"
import useProcessStatus, { getProcessSignBy } from "@/utils/hooks/useProcessStatus"
import { orderPrepay, orderDelete, orderInfo } from "@/services/order"
import { useModel } from "@/store"
import './style.less'

export default withLayout((props) => {

  const $instance = Taro.getCurrentInstance()
  const { orderId } = $instance.router.params
  const { orderList, setOrderList } = useModel('order')
  const [orderInfos, setOrderInfos] = useState()
  const [isAssessVisible, setIsAssessVisible] = useState(false)
  const { processStatus } = useProcessStatus(orderInfos)

  //取消订单
  const cancelPay = () => {
    Taro.showModal({
      title: '提示',
      content: '您确定要取消此订单吗？',
      success: function (res) {
        if (res.confirm) {
          orderDelete(orderId).then((e) => {
            Taro.showToast({
              title: '订单取消成功',
              icon: 'success',
              duration: 2000
            }).then(() => {
              setTimeout(() => {
                var list = [];
                for (var item of orderList) {
                  if (item.orderId != orderId) {
                    list.push(item)
                  }
                }
                setOrderList(list);
                Taro.navigateBack({
                  delta: 1
                })
              }, 1000)
            })
          })
        } else if (res.cancel) {
          console.log('用户点击取消')
        }
      }
    })
  }


  //支付
  const pay = () => {
    orderPrepay(orderId, {
      payType: 'wx',
    }).then((e) => {
      console.log('订单返回', e);
      Taro.showLoading({
        title: '支付中',
      })
      requestPayment(e)
    })
  }
  //微信支付付款
  const requestPayment = (params) => {
    Taro.hideLoading()
    Taro.requestPayment({
      ...params,
      package: params.packageValue,
      success: () => {
        Taro.showToast({
          title: "支付成功",
          icon: "success",
          duration: 1000,
        }).then(() => {
          setTimeout(() => {
            var list = [...orderList];
            for (var item of list) {
              if (item.orderId == orderId) {
                item.payStatus = 1
              }
            }
            setOrderList(list);
            Taro.navigateBack({
              delta: 1
            })
          }, 400)
        })
      },
      fail: (e) => {
        Taro.showToast({
          title: "支付失败",
          icon: "none",
          duration: 2000,
        });
      },
    })
  }

  //弹出弹窗
  const startModle = () => {
    setIsAssessVisible(true)
  }
  //关闭评价弹窗
  const onClose = () => {
    setIsAssessVisible(false)
    var list = [...orderList];
    for (var item of list) {
      if (item.orderId == orderId) {
        item.isEvaluated = 1
      }
    }
    setOrderList(list);
    Taro.navigateBack({
      delta: 1
    })

  }
  //显示底部按钮
  const { processLabel, stateStyle, action: Actions } = useMemo(() => {
    const { label, color } = getProcessSignBy(processStatus)
    let action = <></>;

    switch (processStatus) {
      case 1:
      case 2:
        action = <ButtontWX butText='取消' styleType onClick={cancelPay} butWidth={150} butHeight={39} butFontSize={16} butBorderRadius={49} />;
        break;
      case 4:
        action = <ButtontWX butText='支付' onClick={pay} butWidth={150} butHeight={39} butFontSize={16} butBorderRadius={49} />;
        break;
      case 5:
        action = <ButtontWX butText='评价' onClick={startModle} butWidth={323} butHeight={49} butFontSize={16} butBorderRadius={49} />;
        break;
      case 3:
      case 6:
      default:
        break;
    }
    return {
      processLabel: label,
      stateStyle: color,
      action
    }
  }, [processStatus])

  useEffect(() => {
    if (orderId) {
      orderInfo(orderId).then((res) => {
        setOrderInfos(res)
      })
    } else {
      Taro.showToast({
        title: '暂无订单详情',
        icon: 'error',
        duration: 2000
      }).then(() => {
        setTimeout(() => {
          Taro.navigateBack({
            delta: 1
          })
        }, 1000)
      })
    }
  }, [orderId])

  return (
    <View className='page-index'>
      <View className='index-navbar'>
        <CustomNav title='订单详情' />
      </View>
      {/* 评价弹窗 */}
      <AssessModel orderId={orderId} showCutover={isAssessVisible} onClose={onClose} />
      {/* <BottomMoadl frameTitle='支付方式' flag={showFrame} onRecommend={setRecommend} /> */}
      <View className='orders-listBox-RihtboxBoxOrderViewText'>
        <View className='View-LiftTextTop'>订单编号：<Text>{orderInfos?.orderNo}</Text></View>
        <View>农机名称：<Text>{orderInfos?.machineryName}</Text></View>
        <View>作业面积：<Text>{orderInfos?.amount}</Text></View>
        <View>需求时间：<Text>{formatTimes(orderInfos?.appointmentDate, 'yyyy-MM-dd')}</Text></View>
        <View>下单时间：<Text>{formatTimes(orderInfos?.createDate, 'yyyy-MM-dd')}</Text></View>
        <View>订单状态：<Text style={{ color: `${stateStyle}` }}  >{processLabel}</Text></View>
        <View className='View-LiftTextBotton'>
          <View className='feiyongStyle'>费用：<Text className='feiyongStyle-charges' >{formatPrice(orderInfos?.charges)}</Text></View>
          <View className='feiyongStyle'>状态：<Text style={{ color: `${stateStyle}` }} className='feiyongStyle-stateStyle' >{orderInfos?.payStatus === 1 ? '已付款' : '待付款'}</Text></View>
        </View>
      </View>
      <View className='BottomtBut' >
        {Actions}
      </View>
    </View>
  )
})
