
import { View, Swiper, Image, SwiperItem, Text, Input } from "@tarojs/components"
import { useEffect, useState, useMemo } from "react"
import Taro, { useReachBottom } from "@tarojs/taro"
import addresss from '@/assets/mineImgaes/addresss.png'//地址
import searchs from '@/assets/homesImgaes/searchs.png'//搜索图片
import carsListImga from '@/assets/homesImgaes/carsListImga.png'//农机列表图片
import CarsListContent from "@/components/CarsListContent"
import { getHomeBanner, getMachinery, } from "@/services/homes"
import withLayout from '@/layouts'

import { useModel } from "@/store"
import './HomesCss/style.less'

export default withLayout((props) => {
  const { sserLocation } = useModel('userData')
  const [bannerHome, setBannerHome] = useState([])
  const [carsList, setCarsList] = useState([])

  const [currentPage, setCurrentPage] = useState(1)

  const [isMore, setIsMore] = useState(false)




  useEffect(() => {
    getHomeBanner({ position: 'banner' }).then((e) => {
      setBannerHome(e)
    })
    getMachinery(sserLocation, { pageNum: currentPage, }).then((e) => {
      const records = currentPage === 1 ? e.records || [] : carsList.concat(e.records || [])
      if (e.records.length == 0 && currentPage != 1) {
        setIsMore(true)
        return
      }
      setCarsList(records)
    })
  }, [currentPage, sserLocation])

  const handleScrollToLower = () => {
    if (carsList.length < 9) {
      return;
    } else {
      setCurrentPage(currentPage + 1)
    }
  }

  const goSearch = () => {
    Taro.navigateTo({ url: `/pages/Search/index?location=${sserLocation}` })
  }

  const goToCarsList = () => {//更多
    Taro.navigateTo({ url: `/pages/MoreCars/index` })
  }

  return (
    <scroll-view
      className='scrollView'
      scrollY
      style='height: 100%;'
      onScrollToLower={isMore ? '' : handleScrollToLower}
    >

      <View className='heads-top-box'>
        <View className='heads-top-box-left'>
          <Image src={addresss} className='heads-top-box-left-addresssImg' />
          <Text>邓州市</Text>
          <View className='heads-top-box-left-addresssImg-DownIcon' />
        </View>
        <View className='heads-content-searchClass' onClick={goSearch}>
          <Input disabled type='text' className='heads-content-searchClass-searchInput' placeholder='搜索关键字查询农机' />
          <Image src={searchs} className='heads-content-searchClass-searchInput-searchImg' />
        </View>
      </View>
      <Swiper
        mode='scaleToFill'
        className='swiper-box'
      >
        {bannerHome.map((item, inx) => (
          <SwiperItem key={inx}>
            <Image src={item.thumb} mode='widthFix' className='storeImage' />
          </SwiperItem>
        ))}
      </Swiper>
      <View className='content-header-box'>
        <View className='content-header-box-liftCentent'>
          <Image src={carsListImga} />
          <View>农机列表</View>
        </View>
        <View onClick={goToCarsList} className='content-header-box-rightCentent'>更多&gt;&gt;</View>
      </View>
      <CarsListContent carsList={carsList} />
    </scroll-view>
  )
})
