
import { View, Image, Text } from "@tarojs/components"
import Taro, { useDidShow } from '@tarojs/taro'
import ListPlaceholder from "@/components/ListPlaceholder"
import withLayout from '@/layouts'
import ordersListImga from '@/assets/ordersImages/ordersListImga.png'
import ordersLeft from '@/assets/ordersImages/ordersLeft.png'//订单装饰
import { useEffect, useState } from "react"
import { getOrder } from "@/services/order"
import formatTimes from "@/utils/codeSegment"
import formatPrice from "@/utils/formatPrice"
import { getProcessStatus, getProcessSignBy } from "@/utils/hooks/useProcessStatus"
import { useModel } from "@/store"
import './OrdersCss/style.less'



export default withLayout((props) => {

  const { orderList, setOrderList, pageNum, setPageNum, isMore, setIsMore } = useModel('order')
  
  const handleScrollToLower = () => {
    if (orderList.length < 9) {
      return;
    } else {
      setPageNum(pageNum + 1)
    }
  }
  const orderStates = (item) => {
    const processStatus = getProcessStatus(item)
    const { label: title, color: styleColor } = getProcessSignBy(processStatus)
    return { title, styleColor }
  }

  const handleTobePaid = (id) => {
    Taro.navigateTo({ url: `/pages/OrderInfo/index?orderId=${id}` })
  }
  useEffect(()=>{
    setPageNum(1);
    setIsMore(false);
  },[])
  useEffect(() => {
    getOrder({ pageNum: pageNum, mine: true }).then((e) => {
      const records = pageNum === 1 ? e.records || [] : orderList.concat(e.records || [])
      if (e.records.length == 0 && pageNum != 1) {
        setIsMore(true)
        return
      }
      setOrderList(records)
    })
  }, [pageNum])

  return (
    <scroll-view
      scrollY
      style='height: 100%;'
      onScrollToLower={isMore ? '' : handleScrollToLower}
    >
      <View className='content-header-box-orders'>
        <View className='content-header-box-orders-liftCentent'>
          <Image src={ordersListImga} />
          <View>订单列表</View>
        </View>
      </View>
      {
        orderList?.length > 0 ? orderList.map((item, index) => {
          return (
            <View key={index} className='orders-listBox'>
              <Image src={ordersLeft} />
              <View className='orders-listBox-RihtboxBoxOrderViewText'>
                <View className='View-LiftTextTop' onClick={() => handleTobePaid(item.orderId)} >
                  编号：<Text>{item.orderNo}</Text><Text className='View-LiftTextTop-nextText'>详情&gt;&gt;</Text></View>
                <View>农机名称：<Text>{item.machineryName}</Text></View>
                <View>作业面积：<Text>{item.amount}</Text></View>
                <View>需求时间：<Text>{formatTimes(item.appointmentDate, 'yyyy-MM-dd')}</Text></View>
                <View>下单时间：<Text>{formatTimes(item.createDate, 'yyyy-MM-dd')}</Text></View>
                <View className='View-LiftTextBotton'>
                  <View>订单状态：<Text style={{ color: orderStates(item)?.styleColor }} >{orderStates(item)?.title}</Text></View>
                  <View>费用：<Text className='feiyongStyle'>{formatPrice(item.charges)}</Text></View>
                </View>
              </View>
            </View>
          )
        })
          : <ListPlaceholder title='您还没有新的订单！' />
      }


    </scroll-view>
  )
})
