import Taro from '@tarojs/taro'
import { getQueryString } from './codeSegment'

let appid

export default (url, options) => {
  const { params, skipError, header, ...leftOptions } = options || {}
  const queryStr = getQueryString(params)

  if (!appid) {
    const { miniProgram } = Taro.getAccountInfoSync()
    appid = miniProgram.appId
  }

  const urlWithParams = queryStr ? `${url}?${queryStr}` : url;
  const nwUrl = `${HOST}/api/wx/farmer${urlWithParams}`

  const authToken = Taro.getStorageSync('token')
  const tokenHeader = authToken ? { Authorization: authToken } : {}
  const nwHeader = {
    ...(header || {}),
    ...tokenHeader,
  }

  return new Promise((resolve, reject) => {
    Taro.request({
      ...leftOptions,
      url: nwUrl,
      header: nwHeader,
      success: (res) => {
        const { code, message, data, token } = res.data

        if (token || data?.token) {
          Taro.setStorage({ key: 'token', data: token || data?.token })
        }

        if (code === 1000) {
          resolve(data)

        } else {
          if (!skipError) {
            Taro.showToast({
              title: message || '网络异常',
              icon: 'none',
            })
          }
          reject(message?.indexOf('java') > -1 ? '系统内部错误' : message)
        }
      },

      fail: (err) => {
        console.error(err)



        const message = err.message || err.errMsg || err

        if (!skipError) {
          Taro.showToast({
            title: message,
            icon: 'none',
          })
        }

        reject(message)
      }
    })
  })
}
